@@ -111,31 +111,21 @@ gnome_win32_get_prefixes (gpointer  hmodule,
         *full_prefix = NULL;
         *cp_prefix = NULL;
 
-        if (G_WIN32_HAVE_WIDECHAR_API ()) {
-                /* NT-based Windows has wide char API */
-                if (GetModuleFileNameW ((HMODULE) hmodule, wcbfr, G_N_ELEMENTS (wcbfr))) {
-                        *full_prefix = g_utf16_to_utf8 (wcbfr, -1,
-                                                        NULL, NULL, NULL);
-                        if (GetShortPathNameW (wcbfr, wcbfr, G_N_ELEMENTS (wcbfr)) &&
-                            /* Short pathnames always contain only
-                             * ASCII, I think, but just in case, be
-                             * prepared.
-                             */
-                            WideCharToMultiByte (CP_ACP, 0, wcbfr, -1,
-                                                 cpbfr, G_N_ELEMENTS (cpbfr),
-                                                 NULL, NULL))
-                                *cp_prefix = g_strdup (cpbfr);
-                        else if (*full_prefix)
-                                *cp_prefix = g_locale_from_utf8 (*full_prefix, -1,
-                                                                 NULL, NULL, NULL);
-                }
-        } else {
-                /* Win9x */
-                if (GetModuleFileNameA ((HMODULE) hmodule, cpbfr, G_N_ELEMENTS (cpbfr))) {
-                        *full_prefix = g_locale_to_utf8 (cpbfr, -1,
-                                                         NULL, NULL, NULL);
+        if (GetModuleFileNameW ((HMODULE) hmodule, wcbfr, G_N_ELEMENTS (wcbfr))) {
+                *full_prefix = g_utf16_to_utf8 (wcbfr, -1,
+                                                NULL, NULL, NULL);
+                if (GetShortPathNameW (wcbfr, wcbfr, G_N_ELEMENTS (wcbfr)) &&
+                    /* Short pathnames always contain only
+                     * ASCII, I think, but just in case, be
+                     * prepared.
+                     */
+                    WideCharToMultiByte (CP_ACP, 0, wcbfr, -1,
+                                         cpbfr, G_N_ELEMENTS (cpbfr),
+                                         NULL, NULL))
                         *cp_prefix = g_strdup (cpbfr);
-                }
+                else if (*full_prefix)
+                        *cp_prefix = g_locale_from_utf8 (*full_prefix, -1,
+                                                         NULL, NULL, NULL);
         }
 
         if (*full_prefix != NULL) {
