@@ -31,14 +31,14 @@
 #include <strings.h>
 #include <stdio.h>
 #include <time.h>
-#include <string.h>
 #include <unistd.h>	/* unlink() */
 #include <stdlib.h>	/* atoi() */
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 #include "gnome-util.h"
+#include "gnome-i18n.h"
 #include "gnome-config.h"
 
 #if !defined getc_unlocked && !defined HAVE_GETC_UNLOCKED
@@ -403,8 +403,6 @@ load (const char *file)
 				SecHeader->keys->value = decode_string_and_dup (CharBuffer);
 				state = c == '\n' ? KeyDef : IgnoreToEOL;
 				next = CharBuffer;
-#ifdef GNOME_ENABLE_DEBUG
-#endif
 			} else
 				*next++ = c;
 			break;
@@ -622,26 +620,26 @@ access_config_extended (access_type mode, const char *section_name,
 }
 
 static void
-dump_keys (FILE *profile, TKeys *p)
+dump_keys (GString *profile, TKeys *p)
 {
 	if (!p)
 		return;
 	dump_keys (profile, p->link);
 	if (*p->key_name) {
 		char *t = escape_string_and_dup (p->value);
-		fprintf (profile, "%s=%s\n", p->key_name, t);
+		g_string_append_printf (profile, "%s=%s\n", p->key_name, t);
 		g_free (t);
 	}
 }
 
 static void
-dump_sections (FILE *profile, TSecHeader *p)
+dump_sections (GString *profile, TSecHeader *p)
 {
 	if (!p)
 		return;
 	dump_sections (profile, p->link);
 	if (p->section_name && p->section_name [0]){
-		fprintf (profile, "\n[%s]\n", p->section_name);
+		g_string_append_printf (profile, "\n[%s]\n", p->section_name);
 		dump_keys (profile, p->keys);
 	}
 }
@@ -667,7 +665,7 @@ check_path(char *path, mode_t newmode)
 
 	/*special case if directory exists, this is probably gonna happen
 	  a lot so we don't want to go though checking it part by part*/
-	if (stat(dir, &s) == 0) {
+	if (g_stat(dir, &s) == 0) {
 		g_free(dir);
 		/*check if a directory*/
 		if (!S_ISDIR(s.st_mode))
@@ -700,7 +698,7 @@ check_path(char *path, mode_t newmode)
 		else
 			newpath = g_string_append_c(newpath, G_DIR_SEPARATOR);
 		newpath = g_string_append(newpath,p);
-		if(stat(newpath->str,&s)==0) {
+		if(g_stat(newpath->str,&s)==0) {
 			/*check if a directory*/
 			if(!S_ISDIR(s.st_mode)) {
 				g_string_free(newpath,TRUE);
@@ -729,12 +727,32 @@ check_path(char *path, mode_t newmode)
 }
 
 
+static gboolean
+dump_sections_to_file (TProfile *p)
+{
+	GError *err = NULL;
+	GString *profile = g_string_new("");
+
+	dump_sections (profile, p->section);
+
+	g_file_set_contents(p->filename, profile->str, profile->len, &err);
+
+	g_string_free(profile,TRUE);
+
+	if (err != NULL) {
+		/* TODO Maybe the error should be displayed */
+		g_error_free (err);
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 
 static gboolean
 dump_profile (TProfile *p, gboolean one_only)
 {
 	gboolean ret = TRUE;
-	FILE *profile;
 
 	if (!p)
 		return ret;
@@ -771,9 +789,8 @@ dump_profile (TProfile *p, gboolean one_only)
 			if(p==Current)
 				Current = NULL;
 		} else if (check_path(p->filename,0755) &&
-		    (profile = g_fopen (p->filename, "w")) != NULL){
-			dump_sections (profile, p->section);
-			fclose (profile);
+			dump_sections_to_file(p)){
+			/* File written correctly */
 		} else {
 			/* we failed at actually writing to the file */
 			ret = FALSE;
